Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: third_party/pylint/interfaces.py

Issue 719313003: Revert "pylint: upgrade to 1.3.1" (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/pylint/gui.py ('k') | third_party/pylint/lint.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/pylint/interfaces.py
diff --git a/third_party/pylint/interfaces.py b/third_party/pylint/interfaces.py
index 50f2c8391041a83d784829c7d9e0a1326a7e67a2..3d7bdad6fac27aa1153e2201c2da110eda82f237 100644
--- a/third_party/pylint/interfaces.py
+++ b/third_party/pylint/interfaces.py
@@ -9,8 +9,14 @@
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-"""Interfaces for PyLint objects"""
+# 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+""" Copyright (c) 2002-2003 LOGILAB S.A. (Paris, FRANCE).
+ http://www.logilab.fr/ -- mailto:contact@logilab.fr
+
+Interfaces for PyLint objects
+"""
+
+__revision__ = "$Id: interfaces.py,v 1.9 2004-04-24 12:14:53 syt Exp $"
from logilab.common.interface import Interface
@@ -26,32 +32,52 @@ class IChecker(Interface):
def close(self):
"""called after visiting project (i.e set of modules)"""
+## def open_module(self):
+## """called before visiting a module"""
+
+## def close_module(self):
+## """called after visiting a module"""
+
class IRawChecker(IChecker):
"""interface for checker which need to parse the raw file
"""
- def process_module(self, astroid):
+ def process_module(self, astng):
""" process a module
the module's content is accessible via astroid.file_stream
"""
-class ITokenChecker(IChecker):
- """Interface for checkers that need access to the token list."""
- def process_tokens(self, tokens):
- """Process a module.
+class IASTNGChecker(IChecker):
+ """ interface for checker which prefers receive events according to
+ statement type
+ """
- tokens is a list of all source code tokens in the file.
- """
+class ILinter(Interface):
+ """interface for the linter class
-class IAstroidChecker(IChecker):
- """ interface for checker which prefers receive events according to
- statement type
+ the linter class will generate events to its registered checkers.
+ Each checker may interact with the linter instance using this API
"""
+ def register_checker(self, checker):
+ """register a new checker class
+
+ checker is a class implementing IrawChecker or / and IASTNGChecker
+ """
+
+ def add_message(self, msg_id, line=None, node=None, args=None):
+ """add the message corresponding to the given id.
+
+ If provided, msg is expanded using args
+
+ astng checkers should provide the node argument,
+ raw checkers should provide the line argument.
+ """
+
class IReporter(Interface):
""" reporter collect messages and display results encapsulated in a layout
@@ -69,4 +95,4 @@ class IReporter(Interface):
"""
-__all__ = ('IRawChecker', 'IAstroidChecker', 'ITokenChecker', 'IReporter')
+__all__ = ('IRawChecker', 'IStatable', 'ILinter', 'IReporter')
« no previous file with comments | « third_party/pylint/gui.py ('k') | third_party/pylint/lint.py » ('j') | no next file with comments »

Powered by Google App Engine
@@ -26,32 +32,52 @@ class IChecker(Interface):
""" process a module
- the module's content is accessible via astroid.file_stream
+ the module's content is accessible via astng.file_stream
"""
This is Rietveld 408576698